pub struct WasmKemContext { /* private fields */ }Expand description
WASM-compatible KEM context wrapper
This wrapper provides JavaScript-compatible bindings for KEM operations:
- Integrates with the new modular architecture
- Includes security validation
- Provides consistent error handling
- Supports all KEM algorithms
Implementations
Sourceimpl WasmKemContext
impl WasmKemContext
Sourcepub fn new() -> WasmKemContext
pub fn new() -> WasmKemContext
Create a new WASM KEM context with default provider
Sourcepub fn with_provider(provider: &WasmCryptoProvider) -> WasmKemContext
pub fn with_provider(provider: &WasmCryptoProvider) -> WasmKemContext
Create a new WASM KEM context with custom provider
Sourceimpl WasmKemContext
impl WasmKemContext
Sourcepub fn generate_keypair(
&mut self,
algorithm: &str,
randomness: Option<Uint8Array>,
) -> Result<JsValue, JsValue>
pub fn generate_keypair( &mut self, algorithm: &str, randomness: Option<Uint8Array>, ) -> Result<JsValue, JsValue>
Generate a keypair for the specified algorithm
This method provides secure key generation with:
- Algorithm validation
- Security level verification
- Secure random generation
- Proper error handling
Sourcepub fn encapsulate(
&self,
algorithm: &str,
public_key_data: &Uint8Array,
randomness: Option<Uint8Array>,
) -> Result<JsValue, JsValue>
pub fn encapsulate( &self, algorithm: &str, public_key_data: &Uint8Array, randomness: Option<Uint8Array>, ) -> Result<JsValue, JsValue>
Encapsulate a shared secret using the given public key
This method provides secure encapsulation with:
- Public key validation
- Algorithm verification
- Security level checking
- Proper error handling
Sourcepub fn decapsulate(
&self,
algorithm: &str,
secret_key_data: &Uint8Array,
ciphertext: &Uint8Array,
) -> Result<Vec<u8>, JsValue>
pub fn decapsulate( &self, algorithm: &str, secret_key_data: &Uint8Array, ciphertext: &Uint8Array, ) -> Result<Vec<u8>, JsValue>
Decapsulate a shared secret using the given secret key and ciphertext
This method provides secure decapsulation with:
- Secret key validation
- Ciphertext verification
- Algorithm checking
- Proper error handling
Sourcepub fn security_level(&self) -> u32
pub fn security_level(&self) -> u32
Get the security level of the context
Sourcepub fn is_algorithm_supported(&self, algorithm: &str) -> bool
pub fn is_algorithm_supported(&self, algorithm: &str) -> bool
Check if an algorithm is supported
Sourcepub fn supported_algorithms(&self) -> String
pub fn supported_algorithms(&self) -> String
Get supported algorithms